Method: NMatrix#gesdd!

Defined in:
lib/nmatrix/cruby/math.rb

#gesdd!(workspace_size = nil) ⇒ Object

call-seq: gesdd! -> [u, sigma, v_transpose] gesdd! -> [u, sigma, v_conjugate_transpose] # complex

Compute the singular value decomposition of a matrix using LAPACK's GESDD function. This uses a divide-and-conquer strategy. This is destructive, modifying the source NMatrix. See also #gesvd.

Optionally accepts a workspace_size parameter, which will be honored only if it is larger than what LAPACK requires.



492
493
494
# File 'lib/nmatrix/cruby/math.rb', line 492

def gesdd!(workspace_size=nil)
  NMatrix::LAPACK::gesdd(self, workspace_size)
end