Method: NMatrix#gesvd
- Defined in:
- lib/nmatrix/cruby/math.rb
#gesvd(workspace_size = 1) ⇒ Object
call-seq:
gesvd -> [u, sigma, v_transpose]
gesvd -> [u, sigma, v_conjugate_transpose] # complex
Compute the singular value decomposition of a matrix using LAPACK’s GESVD function.
Optionally accepts a workspace_size parameter, which will be honored only if it is larger than what LAPACK requires.
475 476 477 |
# File 'lib/nmatrix/cruby/math.rb', line 475 def gesvd(workspace_size=1) self.clone.gesvd!(workspace_size) end |